@@ -1,101 +1,108 @@
-# import utils.utils as utils
-# from utils.CustomTx import CustomTxType
-import defichainUtils.utils.utils as utils
-from defichainUtils.utils.CustomTx import CustomTxType
+import utils.utils as utils
+from utils.CustomTx import CustomTxType
+# import defichainUtils.utils.utils as utils
+# from defichainUtils.utils.CustomTx import CustomTxType
 from dataclasses import asdict
 
 
-def decodeCustomTx(hex):
+def decodeCustomTx(hex,DfMarker):
     '''
     Hex String without OP_RETURN and DfTx Marker
     ''' 
-    functionMarker = utils.hexToString(hex[:2])
-    if functionMarker == 'j':
-        res = decodeSetGovVariable(hex[2:],True)
-        if res != None:
-            res['name'] = 'setgovheight'
-    elif functionMarker == 'G':
-        res = decodeSetGovVariable(hex[2:],False)
-        if res != None:
-            res['name'] = 'setgovvariable'
-    elif functionMarker == 's':
-        res = decodePoolSwap(hex[2:])
-        if res != None:
-            res['name'] = 'poolswap'
-    elif functionMarker == 'i':
-        res = decodePoolSwapV2(hex[2:])
-        if res != None:
-            res['name'] = 'compositeswap'
-    elif functionMarker == 'Q':
-        res = decodeDFIP2203(hex[2:])
-        if res != None:
-            res['name'] = 'dfip2203'
-    elif functionMarker == 'l':
-        res = decodeAddPoolLiquidity(hex[2:])
-        if res != None:
-            res['name'] = 'addpoolliquidity'
-    elif functionMarker == 'r':
-        res = decodeRemovePoolLiquidity(hex[2:])
-        if res != None:
-            res['name'] = 'removepoolliquidity'
-    elif functionMarker == 'p':
-        res = decodeCreatePoolPair(hex[2:])
-        if res != None:
-            res['name'] = 'createpoolpair'
-    elif functionMarker == 'B':
-        res = decodeAccountToAccount(hex[2:])
-        if res != None:
-            res['name'] = 'accounttoaccount'
-    elif functionMarker == 'X':
-        res = decodeTakeLoan(hex[2:])
-        if res != None:
-            res['name'] = 'takeloan'
-    elif functionMarker == 'H':
-        res = decodePaybackLoan(hex[2:])
-        if res != None:
-            res['name'] = 'paybackloan'
-    elif functionMarker == 'k':
-        res = decodePaybackLoanV2(hex[2:])
-        if res != None:
-            res['name'] = 'paybackloanv2'
-    elif functionMarker == 'a':
-        res = decodeAnyAccountsToAccounts(hex[2:])
-        if res != None:
-            res['name'] = 'anyaccountstoaccounts'
-    elif functionMarker == 'e':
-        res = decodeCloseVault(hex[2:])
-        if res != None:
-            res['name'] = 'closevault'
-    elif functionMarker == 'V':
-        res = decodeVault(hex[2:])
-        if res != None:
-            res['name'] = 'vault'
-    elif functionMarker == 'v':
-        res = decodeUpdateVault(hex[2:])
-        if res != None:
-            res['name'] = 'updatevault'
-    elif functionMarker == 'I':
-        res = decodeAuctionBid(hex[2:])
-        if res != None:
-            res['name'] = 'auctionbid'
-    elif functionMarker == 'J':
-        res = decodeWithdrawFromVault(hex[2:])
-        if res != None:
-            res['name'] = 'withdrawfromvault'
-    elif functionMarker == 'S':
-        res = decodeDepositToVault(hex[2:])
-        if res != None:
-            res['name'] = 'deposittovault'          
+    DfMarker = utils.hexToString(DfMarker)
+    if DfMarker == 'DfTx':
+        functionMarker = utils.hexToString(hex[:2])
+        if functionMarker == 'j':
+            res = decodeSetGovVariable(hex[2:],True)
+            if res != None:
+                res['name'] = 'setgovheight'
+        elif functionMarker == 'G':
+            res = decodeSetGovVariable(hex[2:],False)
+            if res != None:
+                res['name'] = 'setgovvariable'
+        elif functionMarker == 's':
+            res = decodePoolSwap(hex[2:])
+            if res != None:
+                res['name'] = 'poolswap'
+        elif functionMarker == 'i':
+            res = decodePoolSwapV2(hex[2:])
+            if res != None:
+                res['name'] = 'compositeswap'
+        elif functionMarker == 'Q':
+            res = decodeDFIP2203(hex[2:])
+            if res != None:
+                res['name'] = 'dfip2203'
+        elif functionMarker == 'l':
+            res = decodeAddPoolLiquidity(hex[2:])
+            if res != None:
+                res['name'] = 'addpoolliquidity'
+        elif functionMarker == 'r':
+            res = decodeRemovePoolLiquidity(hex[2:])
+            if res != None:
+                res['name'] = 'removepoolliquidity'
+        elif functionMarker == 'p':
+            res = decodeCreatePoolPair(hex[2:])
+            if res != None:
+                res['name'] = 'createpoolpair'
+        elif functionMarker == 'B':
+            res = decodeAccountToAccount(hex[2:])
+            if res != None:
+                res['name'] = 'accounttoaccount'
+        elif functionMarker == 'X':
+            res = decodeTakeLoan(hex[2:])
+            if res != None:
+                res['name'] = 'takeloan'
+        elif functionMarker == 'H':
+            res = decodePaybackLoan(hex[2:])
+            if res != None:
+                res['name'] = 'paybackloan'
+        elif functionMarker == 'k':
+            res = decodePaybackLoanV2(hex[2:])
+            if res != None:
+                res['name'] = 'paybackloanv2'
+        elif functionMarker == 'a':
+            res = decodeAnyAccountsToAccounts(hex[2:])
+            if res != None:
+                res['name'] = 'anyaccountstoaccounts'
+        elif functionMarker == 'e':
+            res = decodeCloseVault(hex[2:])
+            if res != None:
+                res['name'] = 'closevault'
+        elif functionMarker == 'V':
+            res = decodeVault(hex[2:])
+            if res != None:
+                res['name'] = 'vault'
+        elif functionMarker == 'v':
+            res = decodeUpdateVault(hex[2:])
+            if res != None:
+                res['name'] = 'updatevault'
+        elif functionMarker == 'I':
+            res = decodeAuctionBid(hex[2:])
+            if res != None:
+                res['name'] = 'auctionbid'
+        elif functionMarker == 'J':
+            res = decodeWithdrawFromVault(hex[2:])
+            if res != None:
+                res['name'] = 'withdrawfromvault'
+        elif functionMarker == 'S':
+            res = decodeDepositToVault(hex[2:])
+            if res != None:
+                res['name'] = 'deposittovault'          
+        else:
+            c = CustomTxType()
+            for key, value in asdict(c).items():
+                if value == functionMarker:
+                    return {
+                        'name': str(key).lower(),
+                        'hex': hex[2:]
+                    }
+            return None
+        return res
     else:
-        c = CustomTxType()
-        for key, value in asdict(c).items():
-            if value == functionMarker:
-                return {
-                    'name': str(key).lower(),
-                    'hex': hex[2:]
-                }
-        return None
-    return res
+        return {
+            'txType': DfMarker,
+            'hex': hex
+        }
 
 
 def decodeSetGovVariable(hex,withHeight):
